@@ -7,12 +7,26 @@ This module shoud be imported in a fabfile to deploy an application using pydipl
 """
 
 
+from contextlib import contextmanager
+
 import fabric
 import fabtools
 import pydiploy
 from fabric.api import env
+from pydiploy.decorators import do_verbose
 
 
+@contextmanager
+def wrap_deploy():
+    try:
+        yield
+    except SystemExit:
+        fabric.api.execute(rollback)
+        fabric.api.abort(fabric.colors.red(
+            "Deploy failed rollbacking process launched"))
+
+
+@do_verbose
 def application_packages(update=False):
     """ Installs all packages for django webapp """
     fabtools.require.deb.packages(['gettext'], update=update)
@@ -31,14 +45,14 @@ def application_packages(update=False):
             pydiploy.require.system.install_extra_packages, env.extra_pkg_to_install)
 
 
-def pre_install_backend(commands='/usr/bin/rsync'):
+def pre_install_backend(commands='/usr/bin/rsync', upgrade_circus=False):
     """ Installs requirements for circus & virtualenv env """
     fabric.api.execute(pydiploy.require.system.add_user, commands=commands)
     fabric.api.execute(pydiploy.require.system.set_locale)
     fabric.api.execute(pydiploy.require.system.set_timezone)
     fabric.api.execute(pydiploy.require.system.update_pkg_index)
     fabric.api.execute(application_packages)
-    fabric.api.execute(pydiploy.require.circus.circus_pkg)
+    fabric.api.execute(pydiploy.require.circus.circus_pkg, update=upgrade_circus)
     fabric.api.execute(pydiploy.require.python.virtualenv.virtualenv)
     fabric.api.execute(pydiploy.require.circus.upstart)
 
@@ -52,17 +66,20 @@ def pre_install_frontend():
 
 def deploy_backend(upgrade_pkg=False, **kwargs):
     """ Deploys django webapp with required tag """
-    fabric.api.execute(pydiploy.require.releases_manager.setup)
-    fabric.api.execute(pydiploy.require.releases_manager.deploy_code)
-    fabric.api.execute(pydiploy.require.django.utils.deploy_manage_file)
-    fabric.api.execute(pydiploy.require.django.utils.deploy_wsgi_file)
-    fabric.api.execute(
-        pydiploy.require.python.utils.application_dependencies, upgrade_pkg)
-    fabric.api.execute(pydiploy.require.django.utils.app_settings, **kwargs)
-    fabric.api.execute(pydiploy.require.django.command.django_prepare)
-    fabric.api.execute(pydiploy.require.system.permissions)
-    fabric.api.execute(pydiploy.require.circus.app_reload)
-    fabric.api.execute(pydiploy.require.releases_manager.cleanup)
+    with wrap_deploy():
+        fabric.api.execute(pydiploy.require.releases_manager.setup)
+        fabric.api.execute(pydiploy.require.releases_manager.deploy_code)
+        fabric.api.execute(pydiploy.require.django.utils.deploy_manage_file)
+        fabric.api.execute(pydiploy.require.django.utils.deploy_wsgi_file)
+        fabric.api.execute(
+            pydiploy.require.python.utils.application_dependencies,
+            upgrade_pkg)
+        fabric.api.execute(pydiploy.require.django.utils.app_settings,
+            **kwargs)
+        fabric.api.execute(pydiploy.require.django.command.django_prepare)
+        fabric.api.execute(pydiploy.require.system.permissions)
+        fabric.api.execute(pydiploy.require.circus.app_reload)
+        fabric.api.execute(pydiploy.require.releases_manager.cleanup)
 
 
 def deploy_frontend():
@@ -109,7 +126,7 @@ def set_app_down():
 
 
 def set_app_up():
-    """ Sets app in maintenance mode """
+    """ Sets app up """
     fabric.api.execute(pydiploy.require.nginx.set_website_up)
 
 
@@ -141,6 +158,12 @@ def install_postgres_server(user=None,dbname=None,password=None):
     fabric.api.execute(pydiploy.require.databases.postgres.add_postgres_user,user,password=password)
     fabric.api.execute(pydiploy.require.databases.postgres.add_postgres_database,dbname,owner=user,locale=env.locale)
 
+
 def install_oracle_client():
-    """ Installs oracle client """
+    """ Install oracle client. """
     fabric.api.execute(pydiploy.require.databases.oracle.install_oracle_client)
+
+
+def install_sap_client():
+    """ Install saprfc bindings to an SAP instance. """
+    fabric.api.execute(pydiploy.require.databases.sap.install_sap_client)
