@@ -26,7 +26,7 @@ from pydiploy.django import (deploy_backend as pydiploy_deploy_backend,
 
 
 # edit config here !
-env.user = 'vagrant'  # user for ssh
+
 env.use_sudo = True # use sudo or not
 
 env.remote_owner = 'django'  # remote server user
@@ -36,7 +36,7 @@ env.application_name = 'myapp'   # name of webapp
 env.root_package_name = 'myapp'  # name of app in webapp
 
 env.remote_home = '/home/django'  # remote home root
-env.remote_python_version = 3.3  # python version
+env.remote_python_version = 3.4  # python version
 env.remote_virtualenv_root = join(env.remote_home, '.virtualenvs')  # venv root
 env.remote_virtualenv_dir = join(env.remote_virtualenv_root,
                                  env.application_name)  # venv for webapp dir
@@ -49,6 +49,10 @@ env.keep_releases = 2  # number of old releases to keep before cleaning
 
 # optional parameters
 
+# env.application_type = 'default' # specify another type of application
+
+# env.remote_repo_specific_folder = '' # specify a subfolder for the remote repository
+# env.user = 'my_user'  # user for ssh
 # env.dest_path = '' # if not set using env_local_tmp_dir
 # env.excluded_files = ['pron.jpg'] # file(s) that rsync should exclude when deploying app
 # env.extra_ppa_to_install = ['ppa:vincent-c/ponysay'] # extra ppa source(s) to use
@@ -72,12 +76,20 @@ env.keep_releases = 2  # number of old releases to keep before cleaning
 
 # env.circus_package_name = 'https://github.com/githubaccount/circus/archive/master.zip' # change the package to use to install circus
 # env.no_circus_web = True # true if you don't want circus-web
+# env.circus_backend = 'gevent' # name of circus backend to use
+
+# env.chaussette_backend = 'waitress' # name of chaussette backend to use. You need to add this backend in the app requirement file.
 
 # env.nginx_location_extra_directives = ['proxy_read_timeout 120'] # add directive(s) to nginx config file in location part
-# env.nginx_start_confirmation = True # if True when nginx is not started needs confirmation to start it.
+# env.nginx_force_start = True # if True, it forces to start nginx when nginx is not started
 
 # env.socket_host='localhost' # use it in env method to force a socket host
 
+# env.run_tests_command = 'tox'
+
+# env.media_folder = '/media' # path of the application's media files
+# env.remote_media_folder = '/srv/media/myapp' # remote folder of the application's media files
+
 # fill and uncomment not to pass parameters in term (eg: fab tag:master test --set default_db_host='localhost',default_db_name='my_app_db' )
 # env.default_db_host = 'localhost'
 # env.default_db_name = 'myapp_db'
@@ -88,6 +100,7 @@ env.keep_releases = 2  # number of old releases to keep before cleaning
 @task
 def test():
     """Define test stage"""
+    env.user = 'vagrant'  # user for ssh
     env.roledefs = {
         'web': ['192.168.1.2'],
         'lb': ['192.168.1.3'],
@@ -192,7 +205,7 @@ def deploy():
 @task
 def deploy_backend(update_pkg=False):
     """Deploy code on server"""
-    execute(pydiploy_deploy_backend)
+    execute(pydiploy_deploy_backend, update_pkg)
 
 
 @roles('lb')
