@@ -16,9 +16,8 @@ import os
 
 import fabric
 import fabtools
-
-from pkg_resources import resource_filename, Requirement
 from fabric.api import env
+from pkg_resources import Requirement, resource_filename
 from pydiploy.params import PARAMS
 from pydiploy.require.git import check_tag_exist
 from pydiploy.version import __version__, __version_info__
@@ -38,12 +37,15 @@ def tag(version):
             "tag/branch provided is not in the repository please fix this first"))
 
 
-def init_params():
+def init_params(application_type='default'):
     """ Sets required params and its description """
 
-    # TODO implement mechanism to deploy other technos with specific required
-    # and optional parameters !
-    return PARAMS['default']['required_params'], PARAMS['default']['optional_params']
+    try:
+        required_params, optional_params = PARAMS[application_type]['required_params'], PARAMS[application_type]['optional_params']
+    except KeyError:
+        fabric.api.abort(fabric.colors.red(
+            "application_type '%s' doesn't exists" % application_type))
+    return required_params, optional_params
 
 
 def build_env():
@@ -67,7 +69,10 @@ def build_env():
     if "dest_path" not in env:
         env.dest_path = env.local_tmp_dir
 
-    env.remote_project_dir = os.path.join(env.remote_home, env.server_name)
+    if "server_name" in env:
+        env.remote_project_dir = os.path.join(env.remote_home, env.server_name)
+    else:
+        env.remote_project_dir = os.path.join(env.remote_home, env.application_name)
 
     if "tag" in env:
         env.local_tmp_root_app = os.path.join(env.local_tmp_dir,
@@ -89,29 +94,9 @@ def build_env():
     if "previous_settings_file" not in env:
         env.previous_settings_file = ""
 
+    # populate env vars for current release / n-1 release
     if not "releases" in env:
-        if fabtools.files.is_dir(env.remote_releases_path):
-            env.releases = sorted(fabric.api.run('ls -x %(releases_path)s' %
-                                                 {'releases_path': env.remote_releases_path}).split())
-
-            if len(env.releases) >= 1:
-                env.current_revision = env.releases[-1]
-                env.current_release = "%(releases_path)s/%(current_revision)s" % \
-                                      {'releases_path': env.remote_releases_path,
-                                       'current_revision': env.current_revision}
-                # warning previous settings file before deployement !!!!!
-                env.previous_release_base_package_dir = os.path.join(
-                    env.current_release, env.root_package_name)
-                env.previous_release_settings_dir = os.path.join(
-                    env.previous_release_base_package_dir, 'settings')
-                env.previous_settings_file = os.path.join(
-                    env.previous_release_settings_dir, '%s.py' % env.goal)
-
-            if len(env.releases) > 1:
-                env.previous_revision = env.releases[-2]
-                env.previous_release = "%(releases_path)s/%(previous_revision)s" % \
-                                       {'releases_path': env.remote_releases_path,
-                                        'previous_revision': env.previous_revision}
+        fabric.api.execute(process_releases)
 
     # define main goals
     env.goals = ['dev', 'test', 'prod']
@@ -126,13 +111,18 @@ def build_env():
     else:
         verbose_value = True
 
-    if not test_config(verbose=verbose_value):
+    if 'application_type' in env:
+        application_type = env.application_type
+    else:
+        application_type = 'default'
+
+    if not test_config(verbose=verbose_value, application_type=application_type):
         if not fabric.contrib.console.confirm("Configuration test %s! Do you want to continue?" % fabric.colors.red('failed'), default=False):
             fabric.api.abort("Aborting at user request.")
 
 
 @fabric.api.task
-def test_config(verbose=True):
+def test_config(verbose=True, application_type='default'):
     """ Checks fabfile for required params and optional params """
 
     if "no_config_test" in env:
@@ -142,7 +132,7 @@ def test_config(verbose=True):
     err = []
     req_parameters = []
     opt_parameters = []
-    req_params, opt_params = init_params()
+    req_params, opt_params = init_params(application_type)
     max_req_param_length = max(map(len, req_params.keys()))
     max_req_desc_length = max(map(len, req_params.values()))
     max_opt_param_length = max(map(len, opt_params.keys()))
@@ -229,3 +219,44 @@ def generate_fabfile():
 
     with open(fab_sample) as f:
         return f.read()
+
+
+def generate_fabfile_simple():
+
+    fab_sample_simple = resource_filename("pydiploy", "examples/simple_fabfile.py")
+
+    with open(fab_sample_simple) as f:
+        return f.read()
+
+
+def generate_fabfile_bottle():
+
+    fab_sample_bottle = resource_filename("pydiploy", "examples/bottle_fabfile.py")
+
+    with open(fab_sample_bottle) as f:
+        return f.read()
+
+
+def process_releases():
+    """ Populates env vars for releases (current, old...) """
+    if fabtools.files.is_dir(env.remote_releases_path):
+        env.releases = sorted(fabric.api.run('ls -x %(releases_path)s' %
+                                             {'releases_path': env.remote_releases_path}).split())
+        if len(env.releases) >= 1:
+            env.current_revision = env.releases[-1]
+            env.current_release = "%(releases_path)s/%(current_revision)s" % \
+                                  {'releases_path': env.remote_releases_path,
+                                   'current_revision': env.current_revision}
+            # warning previous settings file before deployement !!!!!
+            env.previous_release_base_package_dir = os.path.join(
+                env.current_release, env.root_package_name)
+            env.previous_release_settings_dir = os.path.join(
+                env.previous_release_base_package_dir, 'settings')
+            env.previous_settings_file = os.path.join(
+                env.previous_release_settings_dir, '%s.py' % env.goal)
+
+        if len(env.releases) > 1:
+            env.previous_revision = env.releases[-2]
+            env.previous_release = "%(releases_path)s/%(previous_revision)s" % \
+                                   {'releases_path': env.remote_releases_path,
+                                    'previous_revision': env.previous_revision}
