@@ -1,4 +1,4 @@
 # -*- coding: utf-8 -*-
 
 from pydiploy.require import (circus, databases, django, git, nginx, python,
-                              releases_manager, system)
+                              releases_manager, system, simple, bottle)
