@@ -9,8 +9,10 @@ Requires functions for ldap
 """
 
 import fabtools
+from pydiploy.decorators import do_verbose
 
 
+@do_verbose
 def ldap_pkg(use_sudo=False, user=None):
     """ Installs ldap packages and dependencies """
 
