@@ -7,8 +7,10 @@ import fabric
 import fabtools
 import pydiploy
 from fabric.api import env
+from pydiploy.decorators import do_verbose
 
 
+@do_verbose
 def set_current():
     """
     Uses current directory for new release
@@ -18,6 +20,7 @@ def set_current():
                        'current_path': env.remote_current_path})
 
 
+@do_verbose
 def setup():
     """
     Configs stuff for deployement
@@ -35,6 +38,8 @@ def setup():
 
     fabric.api.execute(pydiploy.require.system.permissions)
 
+
+@do_verbose
 def cleanup():
     """
     Cleans old stuff on remote server
@@ -51,6 +56,7 @@ def cleanup():
                         {'directories': env.directories})
 
 
+@do_verbose
 def deploy_code():
     """
     Deploys code according to tag in env var
@@ -60,7 +66,8 @@ def deploy_code():
     if "tag" not in env:
         tag_requested = fabric.api.prompt('Please specify target tag used: ')
         while(not pydiploy.require.git.check_tag_exist(tag_requested)):
-            tag_requested = fabric.api.prompt('tag %s unknown please specify valid target tag used: ' % fabric.colors.red(tag_requested))
+            tag_requested = fabric.api.prompt(
+                'tag %s unknown please specify valid target tag used: ' % fabric.colors.red(tag_requested))
 
         env.tag = tag_requested
 
@@ -71,20 +78,25 @@ def deploy_code():
 
     fabric.api.require('tag', provided_by=['tag', 'head'])
     fabric.api.require('remote_project_dir', provided_by=env.goals)
+
     tarball = pydiploy.require.git.archive(env.application_name,
                                            prefix='%s-%s/' % (env.application_name,
                                                               env.tag.lower()),
+                                           specific_folder=env.remote_repo_specific_folder if "remote_repo_specific_folder" in env else "",
                                            tag=env.tag,
                                            remote=env.remote_repo_url)
     with fabric.api.lcd('/tmp'):
         fabric.api.local('tar xvf %s' % os.path.basename(tarball))
 
+    if 'run_tests_command' in env and env.run_tests_command:
+        run_tests()
+
     # TODO: see if some excluded files / dir
     # are not in fact usefull in certain projects
     exclude_files = ['fabfile', 'MANIFEST.in', '*.ignore', 'docs',
-                     'log', 'bin', 'manage.py',
+                     '*.log', 'bin', 'manage.py', '.tox',
                      '%s/wsgi.py' % env.root_package_name, '*.db',
-                     '.gitignore']
+                     '.gitignore', '.gitattributes']
     exclude_files += ['%s/settings/%s.py' % (env.root_package_name, goal)
                       for goal in env.goals]
 
@@ -106,21 +118,22 @@ def deploy_code():
                                                env.remote_shared_path, 'config'),
                                                use_sudo=True)
 
-            exclude_files += cfg_shared_file
+            exclude_files += [cfg_shared_file]
 
     if env.has_key('extra_symlink_dirs'):
         for symlink_dir in env.extra_symlink_dirs:
-            exclude_files += symlink_dir
+            exclude_files += [symlink_dir]
 
     env.remote_current_release = "%(releases_path)s/%(time).0f" % {
         'releases_path': env.remote_releases_path, 'time': time()}
 
     fabric.contrib.project.rsync_project(env.remote_current_release,
                                          '/tmp/%s-%s/' % (
-                                             env.application_name, env.tag.lower(
+                                             env.application_name,
+                                             env.tag.lower(
                                              )),
                                          delete=True,
-                                         extra_opts='--rsync-path="sudo -u %s rsync"' % env.remote_owner,
+                                         extra_opts='--links --rsync-path="sudo -u %s rsync"' % env.remote_owner,
                                          exclude=exclude_files)
 
     fabric.api.sudo(
@@ -131,23 +144,41 @@ def deploy_code():
     fabric.api.execute(symlink)
     # set current directory with new release
     fabric.api.execute(set_current)
-
+    # remove git local git archive tarball
     fabric.api.lcd('rm %s' % tarball)
+    # remove local temp dir unarchived directory
+    fabric.api.lcd('rm -rf /tmp/%s-%s' % (env.application_name, env.tag.lower()))
 
 
+@do_verbose
 def rollback_code():
     """
     Rolls back to the previously deployed version
     """
-    if len(env.releases) >= 2:
-        fabric.api.sudo("rm %(current_path)s; ln -s %(previous_release)s %(current_path)s && rm -rf %(current_release)s" %
-                        {'current_release': env.current_release, 'previous_release': env.previous_release, 'current_path': env.remote_current_path})
+
+    fabric.api.execute(pydiploy.prepare.process_releases)
+    if "releases" in env:
+        nb_releases = len(env.releases)
+        if nb_releases >= 2:
+            fabric.api.sudo("rm %(current_path)s; ln -s %(previous_release)s %(current_path)s && rm -rf %(current_release)s" %
+                            {'current_release': env.current_release, 'previous_release': env.previous_release, 'current_path': env.remote_current_path})
+        # elif nb_releases == 1:
+        elif nb_releases == 1:
+
+            fabric.api.puts(fabric.colors.red(
+                            'No rollback only one release found on remote !'))
+        else:
+            fabric.api.sudo("rm %(current_path)s && rm -rf %(previous_release)s" %
+                            {'current_path': env.remote_current_path, 'previous_release': env.remote_current_release})
 
 
+@do_verbose
 def symlink():
     """
     Updates symlink stuff to the current deployed version
     """
+
+    # TODO : really usefull ? (eg : for php apps ...)
     fabric.api.sudo("ln -nfs %(shared_path)s/log %(current_release)s/log" %
                     {'shared_path': env.remote_shared_path,
                      'current_release': env.remote_current_release})
@@ -166,3 +197,13 @@ def symlink():
                             {'shared_path': env.remote_shared_path,
                              'current_release': env.remote_current_release,
                              'dir_name':  extra_symlink_dir})
+
+@do_verbose
+def run_tests():
+    # run local unit test
+    authorized_commands = ['tox']
+    if env.run_tests_command in authorized_commands:
+        with fabric.api.lcd('/tmp/%s-%s/' % (env.application_name, env.tag.lower())):
+            fabric.api.local(env.run_tests_command)
+    else:
+        fabric.api.abort(fabric.colors.red("wrong test command. Currently, only tox is supported"))
