@@ -57,7 +57,7 @@ class CircusCheck(TestCase):
         self.assertTrue(python_install.called)
 
         self.assertEqual(
-            python_install.call_args_list, [call('circus', use_sudo=True)])
+            python_install.call_args_list, [call('circus', upgrade=False, use_sudo=True)])
 
         self.assertTrue(upload_template.called)
         self.assertTrue(
@@ -78,15 +78,26 @@ class CircusCheck(TestCase):
         circus_pkg()
         self.assertEqual(
             python_install.call_args_list[1], call(
-                'https://github.com/githubaccount/circus/archive/master.zip', use_sudo=True)
+                'https://github.com/githubaccount/circus/archive/master.zip', upgrade=False, use_sudo=True)
         )
+
         # test no_circus_web
         del env['no_circus_web']
         del env['circus_package_name']
         circus_pkg()
         self.assertEqual(
-            python_install.call_args_list[-3:], [call('circus', use_sudo=True),
-                                                 call('circus-web', use_sudo=True), call('gevent', use_sudo=True)])
+            python_install.call_args_list[-3:], [call('circus', use_sudo=True, upgrade=False),
+                                                 call('circus-web', use_sudo=True, upgrade=False),
+                                                 call('gevent', use_sudo=True, upgrade=False)])
+
+        # test circus_backend
+        env.circus_backend = "test_circus_backend"
+        circus_pkg()
+        self.assertEqual(
+            python_install.call_args_list[-4:], [call('circus', use_sudo=True, upgrade=False),
+                                                 call('circus-web', use_sudo=True, upgrade=False),
+                                                 call('gevent', use_sudo=True, upgrade=False),
+                                                 call('test_circus_backend', use_sudo=True, upgrade=False)])
 
     @patch('fabtools.files.upload_template', return_value=Mock())
     def test_app_circus_conf(self, upload_template):
